@@ -143,7 +143,7 @@ class DAppTonClient(TonClient):
 
     def _parse_broadcast_result(self, result, waited) -> BroadcastResult:
         if "status" in result:
-            if result["status"] == 1:
+            if result["status"] == 1 and waited:
                 status = BroadcastStatusEnum.commited
             else:
                 status = BroadcastStatusEnum.broadcasted
